'use strict';

const Input = require('postcss/lib/input');
const Root = require('postcss/lib/root');
const htmlParser = require('./html-parser');
const mdParser = require('./markdown-parser');
const BlockFixer = require('./block-fixer');

function parser (source, opts) {
	// Skip known style sheet files
	if (opts.from && /\.(?:css|(?:wx|le|sa|sc|s)ss|styl(?:us)?)(?:\?.+)?$/i.test(opts.from)) {
		return;
	}

	source = source && source.toString();
	const styleTag = htmlParser(source);
	const stylesMd = mdParser(source);
	if (!styleTag && !stylesMd) {
		return;
	}
	const document = new Root();
	const documentLocalFixer = new BlockFixer(source);
	let index = 0;
	[].concat(styleTag).concat(stylesMd).filter(style => {
		return style && style.content.trim();
	}).sort(function (a, b) {
		return a.startIndex - b.startIndex;
	}).forEach(style => {
		const localFixer = documentLocalFixer.block(style);
		const root = localFixer.parse(opts);
		root.raws.beforeStart = source.slice(index, style.startIndex);
		index = style.startIndex + style.content.length;
		document.nodes.push(root);
	});
	document.raws.afterEnd = source.slice(index);
	document.source = {
		input: new Input(source, opts),
		start: {
			line: 1,
			column: 1,
		},
	};

	document.each = callback => {
		let wasBreak, lastResult;
		document.nodes.forEach(node => {
			const result = node.each(callback);
			if ( result === false ) {
				wasBreak = true;
			} else {
				lastResult = result;
			}
		});
		if (wasBreak) {
			return false;
		} else {
			return lastResult;
		}
	};

	return document;
}

module.exports = parser;
